# setup.py
from setuptools import setup, find_packages

setup(
    name="wktools-langflow",
    version="0.1.21",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],  # Add any dependencies here
    description="A tools for langflow",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/kokhou/jwtools",
    author="kokhou",
    author_email="kokhou.choi@gmail.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.10',
)



from typing import Dict

from langchain_core.utils import get_from_dict_or_env
from pydantic.v1 import root_validator, BaseModel
import requests
import json


class LoanWrapper(BaseModel):
    openai_api_key: str
    user_id: str

    class Config:
        extra = "forbid"

    # noinspection PyMethodParameters
    @root_validator(pre=True)
    def validate_environment(cls, values: Dict) -> Dict:
        """Validate that api key and endpoint exists in environment."""
        user_id = get_from_dict_or_env(
            values, "user_id", "USER_ID"
        )
        values["user_id"] = user_id

        openai_api_key = get_from_dict_or_env(
            values, "openai_api_key", "OPENAI_API_KEY"
        )
        values["openai_api_key"] = openai_api_key

        return values


    def get_user_loan_profiles(self):
        url = f"http://localhost:8000/api/loans/user/{self.user_id}"
        headers = {
            "Accept": "application/json",
            "Content-Type": "application/json"
        }

        try:
            response = requests.get(url, headers=headers)
            response.raise_for_status()  # Raise an exception for HTTP errors
            print(response.json())

            limited_results = []
            for result in json.loads(response.content):
                limited_result = {
                "snippet": result,
                }
                limited_results.append(limited_result)

            return limited_results
        except requests.exceptions.RequestException as e:
            print(f"An error occurred: {e}")



"""Tool for the Loan API (get user's loan profiles)."""

from typing import Optional, Type

from langchain_core.callbacks import CallbackManagerForToolRun
from langchain_core.pydantic_v1 import BaseModel, Field
from langchain_core.tools import BaseTool

from wktools_langflow.wrapper.loan_wrapper import LoanWrapper


class LoanQueryInput(BaseModel):
    """Input for the LoanQueryInput tool."""

    user_id: str = Field(description="user's id", default="wk")


class LoanQueryRun(BaseTool):
    """Tool for the Loan API (get user's loan profiles)."""

    name: str = "loan"
    description: str = (
        "A wrapper for loan. "
        "Useful for when you need to answer questions about current user's loans. "
        "Get user's loan profiles.")
    api_wrapper: LoanWrapper

    args_schema: Type[BaseModel] = LoanQueryInput

    def _run(
        self,
        run_manager: Optional[CallbackManagerForToolRun] = None,
    ) -> str:
        """Use the Loan tool."""
        return self.api_wrapper.get_user_loan_profiles()


